@@ -9,6 +9,7 @@ def getOrElse(default, value):
 
 blue='blue'
 closed='closed'
+create='create'
 doing='doing'
 green='green'
 made='made'
@@ -18,6 +19,7 @@ red='red'
 restarted='restarted'
 started='started'
 transferred='transferred'
+update='update'
 
 def blinkString(text, blink=True, color="black", bold=False) -> Text:
     if blink:
