@@ -25,14 +25,14 @@ def null2blanck(str):
     return '' if str == 'null' else str
 
 
-def ExecuteStroredPros(storedProcName, parametrs):
+def ExecuteStoredProc(storedProcName, parametrs):
     c = connection.cursor()
     try:
-        c.execute("BEGIN")
+        # c.execute("BEGIN")
         res = c.callproc(storedProcName, parametrs)
-        # results = c.fetchone()
-        c.execute("COMMIT")
-        # return results
+        results, = c.fetchone()
+        # c.execute("COMMIT")
+        return results
     finally:
         c.close()
 
