@@ -81,16 +81,22 @@ def create_view(sql_str, params=[], view_name=None) -> None:
         settings.LOCKS.release(key)
 
 
-def create_tmp_table(fields_str=None, sql_str=None, on_commit='delete rows', params=[], indexes=[], unique_indexes=[], table_name=None, drop=True) -> None:
+def create_table(fields_str=None, sql_str=None, temporary='', on_commit=None, params=[], indexes=[], unique_indexes=[], primary_key=None, table_name=None, drop=True) -> None:
     if table_name == None:
         raise Exception(f'Table must have name')
 
-    if exists_base_object(table_name):
-        return table_name
-
     key = f'create_tmp_table{table_name}'
     settings.LOCKS.acquire(key)
 
+    pk_str = ''
+    if primary_key != None:
+        if not isinstance(primary_key, list):
+            primary_key = [primary_key]
+
+        pk_str = f'''ALTER TABLE {table_name}
+                    ADD CONSTRAINT {table_name}_pk
+                        PRIMARY KEY ({','.join(primary_key)});'''
+
     indexes_str = ''
     if isinstance(indexes, list):
         indexes = [f'''CREATE INDEX {table_name}_{index}_idx ON {table_name} USING btree ("{index}")''' for index in indexes]
@@ -103,16 +109,18 @@ def create_tmp_table(fields_str=None, sql_str=None, on_commit='delete rows', par
 
     sql_txt = ''
     if drop:
-        sql_txt = f'''DROP table IF EXISTS {table_name} CASCADE;'''
+        sql_txt = f'''DROP TABLE IF EXISTS {table_name} CASCADE;'''
 
     on_commit_str = f'ON COMMIT {on_commit}'
     if on_commit == None:
         on_commit_str = ''
 
     if sql_str == None:
-        sql_txt += f'''CREATE TEMPORARY TABLE {table_name} ({fields_str}) {on_commit_str};'''
+        sql_txt += f'''CREATE {temporary} TABLE {table_name} ({fields_str}) {on_commit_str};'''
     else:
-        sql_txt += f'''CREATE TEMPORARY TABLE {table_name} as ({sql_str}); {on_commit_str};'''
+        sql_txt += f'''CREATE {temporary} TABLE {table_name} as ({sql_str}); {on_commit_str};'''
+
+    sql_txt += pk_str
     sql_txt += indexes_str
     sql_txt += unique_indexes_str
 
@@ -128,6 +136,20 @@ def create_tmp_table(fields_str=None, sql_str=None, on_commit='delete rows', par
         settings.LOCKS.release(key)
 
 
+def create_tmp_table(fields_str=None, sql_str=None, on_commit='delete rows', params=[], indexes=[], unique_indexes=[], table_name=None, drop=True) -> None:
+    create_table(
+        drop=drop,
+        fields_str=fields_str,
+        indexes=indexes,
+        on_commit=on_commit,
+        params=params,
+        sql_str=sql_str,
+        table_name=table_name,
+        temporary='TEMPORARY',
+        unique_indexes=unique_indexes,
+    )
+
+
 def drop_mat_view(mat_view_name) -> bool:
     if not exists_base_object(mat_view_name):
         return False
