@@ -63,6 +63,15 @@ class DSRequest(RPCRequest):
                 self._user = User.objects.get(id=self.httpHeaders.USER_ID)
                 return self._user
             else:
+                if self.transaction != None:
+                    operations = self.transaction.operations
+                    if isinstance(operations, list):
+                        for operation in operations:
+                            data = operation.data
+                            if data.httpHeaders != None and data.httpHeaders.USER_ID != None:
+                                self._user = User.objects.get(id=data.httpHeaders.USER_ID)
+                                return self._user
+
                 raise Exception('user not enable type')
         return self._user
 
