@@ -1,5 +1,3 @@
-from django.utils.translation import ugettext_lazy as _
-
 import logging
 
 from isc_common.auth.models.user import User
@@ -10,20 +8,7 @@ logger = logging.getLogger(__name__)
 
 
 class AuditHistoryQuerySet(AuditQuerySet):
-    def delete(self):
-        return super().delete()
-
-    def soft_delete(self):
-        return super().soft_delete()
-
-    def soft_restore(self):
-        return super().soft_restore()
-
-    def create(self, **kwargs):
-        return super().create(**kwargs)
-
-    def filter(self, *args, **kwargs):
-        return super().filter(*args, **kwargs)
+    pass
 
 
 class AuditHistoryManager(AuditManager):
