@@ -4,7 +4,7 @@ from itertools import chain
 from bitfield import BitHandler, Bit
 from django.db.models import ForeignKey
 
-from isc_common import setAttr
+from isc_common import setAttr, Stack
 from isc_common.fields.related import ForeignKeyProtect
 
 
@@ -147,3 +147,17 @@ def model_2_dict(instance, fields=None, exclude=None):
         else:
             data[f.name] = f.value_from_object(instance)
     return data
+
+def compare_2_dict(dict1, dict2):
+    if not isinstance(dict1, dict):
+        raise Exception(f'dict1 must be dict')
+
+    if not isinstance(dict2, dict):
+        raise Exception(f'dict2 must be dict')
+
+    messages = []
+
+    for x_values, y_values in zip(dict1.items(), dict2.items()):
+        if x_values != y_values:
+            messages.append(f'{x_values} != {y_values}')
+    return messages
