@@ -12,3 +12,9 @@ def get_NullStr(str):
         return ''
     else:
         return str
+
+def StrToBytes(mystring):
+ return mystring.encode('utf-8')
+
+def BytesToStr(mybytes):
+ return mybytes.decode('utf-8')
