@@ -1,10 +1,10 @@
-from isc_common.http.DSResponse import DSResponseUpdate, DSResponseAdd, DSResponse, JsonResponseWithException
+from isc_common.http.DSResponse import DSResponseUpdate, DSResponseAdd, DSResponse, JsonResponseWithException, JsonResponseWithExceptionOld
 from isc_common.http.RPCResponse import RPCResponseConstant
 from isc_common.http.response import JsonResponse
 from isc_common.models.params import Params, ParamsManager
 
 
-@JsonResponseWithException()
+JsonResponseWithExceptionOld()
 def Params_Fetch(request):
     return JsonResponse(
         DSResponse(
@@ -17,7 +17,7 @@ def Params_Fetch(request):
             ),
             status=RPCResponseConstant.statusSuccess).response)
 
-@JsonResponseWithException()
+JsonResponseWithExceptionOld()
 def Params_Add(request):
     return JsonResponse(DSResponseAdd(data=Params.objects.createFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)
 
@@ -31,28 +31,28 @@ def Params_Update1(request):
     return JsonResponse(DSResponseUpdate(data=Params.objects.update1FromRequest(request), status=RPCResponseConstant.statusSuccess).response)
 
 
-@JsonResponseWithException()
+JsonResponseWithExceptionOld()
 def Params_Remove(request):
     return JsonResponse(DSResponse(request=request, data=Params.objects.deleteFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)
 
-@JsonResponseWithException()
+@JsonResponseWithExceptionOld()
 def Params_Remove1(request):
     return JsonResponse(DSResponse(request=request, data=Params.objects.deleteFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)
 
-@JsonResponseWithException()
+JsonResponseWithExceptionOld()
 def Params_Lookup(request):
     return JsonResponse(DSResponse(request=request, data=Params.objects.lookupFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)
 
 
-@JsonResponseWithException()
+JsonResponseWithExceptionOld()
 def Params_Info(request):
     return JsonResponse(DSResponse(request=request, data=Params.objects.get_queryset().get_info(request=request), status=RPCResponseConstant.statusSuccess).response)
 
 
-@JsonResponseWithException()
+JsonResponseWithExceptionOld()
 def Params_Get(request):
     return JsonResponse(DSResponse(request=request, data=Params.objects.get_queryset().get_params(request=request), status=RPCResponseConstant.statusSuccess).response)
 
-@JsonResponseWithException()
+JsonResponseWithExceptionOld()
 def Params_GetKeyValue(request):
     return JsonResponse(DSResponse(request=request, data=Params.objects.get_queryset().get_params_key(request=request), status=RPCResponseConstant.statusSuccess).response)
